"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useConnectionByState = exports.useConnectionById = exports.useConnections = void 0;
const core_1 = require("@aries-framework/core");
const react_1 = require("react");
const React = __importStar(require("react"));
const recordUtils_1 = require("./recordUtils");
const ConnectionContext = (0, react_1.createContext)(undefined);
const useConnections = () => {
    const connectionContext = (0, react_1.useContext)(ConnectionContext);
    if (!connectionContext) {
        throw new Error('useConnections must be used within a ConnectionContextProvider');
    }
    return connectionContext;
};
exports.useConnections = useConnections;
const useConnectionById = (id) => {
    const { records: connections } = (0, exports.useConnections)();
    return connections.find((c) => c.id === id);
};
exports.useConnectionById = useConnectionById;
const useConnectionByState = (state) => {
    const { records: connections } = (0, exports.useConnections)();
    const filteredConnections = (0, react_1.useMemo)(() => connections.filter((c) => c.state === state), [connections, state]);
    return filteredConnections;
};
exports.useConnectionByState = useConnectionByState;
const ConnectionProvider = ({ agent, children }) => {
    const [state, setState] = (0, react_1.useState)({
        records: [],
        loading: true,
    });
    const setInitialState = async () => {
        if (agent) {
            const records = await agent.connections.getAll();
            setState({ records, loading: false });
        }
    };
    (0, react_1.useEffect)(() => {
        setInitialState();
    }, [agent]);
    (0, react_1.useEffect)(() => {
        if (!state.loading) {
            const connectionAdded$ = (0, recordUtils_1.recordsAddedByType)(agent, core_1.ConnectionRecord).subscribe((record) => setState((0, recordUtils_1.addRecord)(record, state)));
            const connectionUpdated$ = (0, recordUtils_1.recordsUpdatedByType)(agent, core_1.ConnectionRecord).subscribe((record) => setState((0, recordUtils_1.updateRecord)(record, state)));
            const connectionRemoved$ = (0, recordUtils_1.recordsRemovedByType)(agent, core_1.ConnectionRecord).subscribe((record) => setState((0, recordUtils_1.removeRecord)(record, state)));
            return () => {
                connectionAdded$.unsubscribe();
                connectionUpdated$.unsubscribe();
                connectionRemoved$.unsubscribe();
            };
        }
    }, [state, agent]);
    return React.createElement(ConnectionContext.Provider, { value: state }, children);
};
exports.default = ConnectionProvider;
//# sourceMappingURL=ConnectionProvider.js.map