"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useProofByState = exports.useProofById = exports.useProofs = void 0;
const core_1 = require("@aries-framework/core");
const react_1 = require("react");
const React = __importStar(require("react"));
const recordUtils_1 = require("./recordUtils");
const ProofContext = (0, react_1.createContext)(undefined);
const useProofs = () => {
    const proofContext = (0, react_1.useContext)(ProofContext);
    if (!proofContext) {
        throw new Error('useProofs must be used within a ProofContextProvider');
    }
    return proofContext;
};
exports.useProofs = useProofs;
const useProofById = (id) => {
    const { records: proofs } = (0, exports.useProofs)();
    return proofs.find((p) => p.id === id);
};
exports.useProofById = useProofById;
const useProofByState = (state) => {
    const { records: proofs } = (0, exports.useProofs)();
    const filteredProofs = (0, react_1.useMemo)(() => proofs.filter((p) => p.state === state), [proofs, state]);
    return filteredProofs;
};
exports.useProofByState = useProofByState;
const ProofProvider = ({ agent, children }) => {
    const [state, setState] = (0, react_1.useState)({
        records: [],
        loading: true,
    });
    const setInitialState = async () => {
        if (agent) {
            const records = await agent.proofs.getAll();
            setState({ records, loading: false });
        }
    };
    (0, react_1.useEffect)(() => {
        setInitialState();
    }, [agent]);
    (0, react_1.useEffect)(() => {
        if (!state.loading) {
            const proofAdded$ = (0, recordUtils_1.recordsAddedByType)(agent, core_1.ProofRecord).subscribe((record) => setState((0, recordUtils_1.addRecord)(record, state)));
            const proofUpdated$ = (0, recordUtils_1.recordsUpdatedByType)(agent, core_1.ProofRecord).subscribe((record) => setState((0, recordUtils_1.updateRecord)(record, state)));
            const proofRemoved$ = (0, recordUtils_1.recordsRemovedByType)(agent, core_1.ProofRecord).subscribe((record) => setState((0, recordUtils_1.removeRecord)(record, state)));
            return () => {
                proofAdded$ === null || proofAdded$ === void 0 ? void 0 : proofAdded$.unsubscribe();
                proofUpdated$ === null || proofUpdated$ === void 0 ? void 0 : proofUpdated$.unsubscribe();
                proofRemoved$ === null || proofRemoved$ === void 0 ? void 0 : proofRemoved$.unsubscribe();
            };
        }
    }, [state, agent]);
    return React.createElement(ProofContext.Provider, { value: state }, children);
};
exports.default = ProofProvider;
//# sourceMappingURL=ProofProvider.js.map