"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.recordsRemovedByType = exports.recordsUpdatedByType = exports.recordsAddedByType = exports.removeRecord = exports.updateRecord = exports.addRecord = void 0;
const core_1 = require("@aries-framework/core");
const rxjs_1 = require("rxjs");
const addRecord = (record, state) => {
    const newRecordsState = [...state.records];
    newRecordsState.unshift(record);
    return {
        loading: state.loading,
        records: newRecordsState,
    };
};
exports.addRecord = addRecord;
const updateRecord = (record, state) => {
    const newRecordsState = [...state.records];
    const index = newRecordsState.findIndex((r) => r.id === record.id);
    if (index > -1) {
        newRecordsState[index] = record;
    }
    return {
        loading: state.loading,
        records: newRecordsState,
    };
};
exports.updateRecord = updateRecord;
const removeRecord = (record, state) => {
    const newRecordsState = state.records.filter((r) => r.id !== record.id);
    return {
        loading: state.loading,
        records: newRecordsState,
    };
};
exports.removeRecord = removeRecord;
const filterByType = (recordClass) => {
    return (0, rxjs_1.pipe)((0, rxjs_1.map)((event) => event.payload.record), (0, rxjs_1.filter)((record) => record.type === recordClass.type));
};
const recordsAddedByType = (agent, recordClass) => {
    if (!agent) {
        throw new Error('Agent is required to subscribe to events');
    }
    return agent === null || agent === void 0 ? void 0 : agent.events.observable(core_1.RepositoryEventTypes.RecordSaved).pipe(filterByType(recordClass));
};
exports.recordsAddedByType = recordsAddedByType;
const recordsUpdatedByType = (agent, recordClass) => {
    if (!agent) {
        throw new Error('Agent is required to subscribe to events');
    }
    return agent === null || agent === void 0 ? void 0 : agent.events.observable(core_1.RepositoryEventTypes.RecordUpdated).pipe(filterByType(recordClass));
};
exports.recordsUpdatedByType = recordsUpdatedByType;
const recordsRemovedByType = (agent, recordClass) => {
    if (!agent) {
        throw new Error('Agent is required to subscribe to events');
    }
    return agent === null || agent === void 0 ? void 0 : agent.events.observable(core_1.RepositoryEventTypes.RecordDeleted).pipe(filterByType(recordClass));
};
exports.recordsRemovedByType = recordsRemovedByType;
//# sourceMappingURL=recordUtils.js.map